Attribute VB_Name = "basEdit"
'----------------------------------------------------------------------
' Module Name:  Ampigpz2
' Author:       Kenneth Ives
' Created:      Thursday, July 02,1998 @ 8:05:16 am (Vers: 2.0.0001)
'
' Description:  This module performs the usual edit functions that
'                   are considered standard.
'
'----------------------------------------------------------------------
Option Explicit

Public Sub Edit_Paste()

'----------------------------------------------------------------------
' Name:         Edit_Paste
' Author:       Kenneth Ives
' Created:      Thursday, July 02,1998 @ 8:28:58 am (Vers: 2.0.0001)
'
' Description:  Copy whatever text is being held in the clipboard and
'                   then paste it in the text box. See Keydown event for
'                   the text boxes to see an example of the code calling
'                   this routine.
'
' Inputs:       None.
'
' Results:      The text loaded into the clipboard will be pasted in
'                   the text box at the cursor location.
'----------------------------------------------------------------------

'----------------------------------------------------------------------
' Verify this is a text box that the cursor is over
'----------------------------------------------------------------------
  If TypeOf Screen.ActiveControl Is TextBox Then
      '
      ' unload clipboard into the textbox
      Screen.ActiveControl.SelText = Clipboard.GetText()
  End If

End Sub

Public Function CenterText(ByVal sTemp As String, Optional vntNumChars As Variant)
    
' -----------------------------------------------
' Define local variables
' -----------------------------------------------
  Dim nNumChars As Integer
  Dim nLeftOver As Integer
  Dim nAddToRight As Integer
    
' -----------------------------------------------
' See if there is a max string length passed
' -----------------------------------------------
  If Not IsMissing(vntNumChars) Then
      nNumChars = vntNumChars
  Else
      nNumChars = 80  ' default to 80
  End If

' -----------------------------------------------
' Subtract the length of the incoming string
' from the max length allowed
' -----------------------------------------------
  nLeftOver = nNumChars - Len(sTemp)
    
' -----------------------------------------------
' If there is something left over then calculate
' half of that value and prefixthe string with
' that numbe rof blank spaces.
' -----------------------------------------------
  If nLeftOver > 0 Then
      sTemp = Space(nLeftOver \ 2) & sTemp
  End If
    
' -----------------------------------------------
' Calculate number of spaces to the right
' -----------------------------------------------
  nAddToRight = nNumChars - Len(sTemp)
  
' -----------------------------------------------
' Append that number of blank spaces to the right
' -----------------------------------------------
  If nAddToRight > 0 Then
      sTemp = sTemp & Space(nAddToRight)
  End If
  
' -----------------------------------------------
' Return the centered text string.  In most
' cases we remove the trailing blanks.  In
' some unique cases we may want to remove the
' RTRIM function and retain those trailing
' blank spaces.
' -----------------------------------------------
  CenterText = RTrim(sTemp)
 
End Function

Public Sub Edit_Copy()

'----------------------------------------------------------------------
' Name:         Edit_Copy
' Author:       Kenneth Ives
' Created:      Thursday, July 02,1998 @ 8:08:44 am (Vers: 2.0.0001)
'
' Description:  Copy highlighted text to the clipboard.  See Keydown
'                   event for the text boxes to see an example of the
'                   code calling this routine.
'
' Inputs:       When the user highlights text with the cursor and
'                   presses CTRL+C to perform a copy function.
'
' Results:      The highlighted text is loaded into the clipboard.
'----------------------------------------------------------------------

'----------------------------------------------------------------------
' Verify this is a text box that the cursor is over
'----------------------------------------------------------------------
  If TypeOf Screen.ActiveControl Is TextBox Then
      '
      ' clear the clipboard
      Clipboard.Clear
      '
      ' load clipboard with the highlighted text
      Clipboard.SetText Screen.ActiveControl.SelText
  End If
  
End Sub

Public Sub Edit_Cut()

'----------------------------------------------------------------------
' Name:         Edit_Cut
' Author:       Kenneth Ives
' Created:      Thursday, July 02,1998 @ 8:28:58 am (Vers: 2.0.0001)
'
' Description:  Copy highlighted text to the clipboard and then
'                   remove it from the text box. See Keydown event for
'                   the text boxes to see an example of the code calling
'                   this routine.
'
' Inputs:       When the user highlights text with the cursor and
'                   presses CTRL+X to perform a cut function.
'
' Results:      The highlighted text is loaded into the clipboard.
'----------------------------------------------------------------------

'----------------------------------------------------------------------
' Verify this is a text box that the cursor is over
'----------------------------------------------------------------------
  If TypeOf Screen.ActiveControl Is TextBox Then
      '
      ' clear the clipboard
      Clipboard.Clear
      '
      ' load clipboard with the highlighted text
      Clipboard.SetText Screen.ActiveControl.SelText
      '
      ' empty the textbox
      Screen.ActiveControl.SelText = ""
  End If

End Sub

Public Sub Edit_Delete()

'----------------------------------------------------------------------
' Name:         Edit_Delete
' Author:       Kenneth Ives
' Created:      Thursday, July 02,1998 @ 8:28:58 am (Vers: 2.0.0001)
'
' Description:  Copy highlighted text to the clipboard and then
'                   remove it from the text box. See Keydown event for
'                   the text boxes to see an example of the code calling
'                   this routine.
'
' Inputs:       When the user highlights text with the cursor and
'                   presses CTRL+X to perform a cut function.
'
' Results:      The highlighted text is loaded into the clipboard
'                   and then the clipboard is emptied.
'----------------------------------------------------------------------

'----------------------------------------------------------------------
' Verify this is a text box that the cursor is over
'----------------------------------------------------------------------
  If TypeOf Screen.ActiveControl Is TextBox Then
      '
      ' remove the highlighted text from the textbox
      Screen.ActiveControl.SelText = ""
  End If
  
End Sub
